@@ -1,8 +1,9 @@
 #' RobinHood API: Option Contract Instruments
 #'
 #' @param RH object of class RobinHood
-#' @param option_instrument_url (string) url 
-#' @import curl jsonlite magrittr lubridate
+#' @param option_instrument_url (string) url
+#' @import curl magrittr
+#' @export
 api_option_instruments <- function(RH, option_instrument_url) {
 
   option_instrument_url <- option_instrument_url
@@ -12,7 +13,7 @@ api_option_instruments <- function(RH, option_instrument_url) {
     handle_setheaders("Authorization" = paste("Bearer", RH$tokens.access_token)) %>%
     curl_fetch_memory(url = option_instrument_url)
 
-  option_instruments <- fromJSON(rawToChar(option_instruments$content))
+  option_instruments <- jsonlite::fromJSON(rawToChar(option_instruments$content))
   option_instruments <- data.frame(option_instruments)
 
   if (option_instruments$type == "call") {
@@ -25,7 +26,6 @@ api_option_instruments <- function(RH, option_instrument_url) {
     option_instruments$created_at <- lubridate::ymd_hms(option_instruments$created_at)
     option_instruments$updated_at <- lubridate::ymd_hms(option_instruments$updated_at)
 
-    option_instruments <- option_instruments[, !names(option_instruments) %in% c("url", "chain_id", "id")]
   }
 
   return(option_instruments)
